@@ -103,7 +103,7 @@ class SearchString(Generic[Data]):
         pattern = pattern.replace(WORD_BOUNDARY_CHAR, WORD_BOUNDARY)
         return pattern
 
-    def _pop_sentence_break_if_needed(self):
+    def _pop_sentence_break_if_needed(self) -> None:
         """
         Removes the last sentence break from the matched sentences list, if
         there is one
@@ -112,7 +112,7 @@ class SearchString(Generic[Data]):
         if ms and ms[-1] == SENTENCE_BREAK:
             ms.pop()
 
-    def _reset_matched_sentences(self):
+    def _reset_matched_sentences(self) -> None:
         """Reset the matched sentences list to an empty list"""
         self.matched_sentences = []
 
@@ -350,6 +350,21 @@ class SearchString(Generic[Data]):
 
         return f'SearchString({inner})'
 
+    @property
+    def long_str(self) -> str:
+        """Long multiline string representation of the SearchString"""
+        fst_str = self._pattern_to_str(self.first_str, self.first_str_global)
+        snd_str = self._pattern_to_str(self.second_str, self.second_str_global)
+        third_str = self._pattern_to_str(self.third_str, self.third_str_global)
+        not_str = self._pattern_to_str(self.not_str, self.not_str_global)
+        return '\n\n'.join([
+            f'{self.data}-søgeord',
+            f'Første søgestreng: {fst_str}',
+            f'Anden søgestreng: {snd_str}',
+            *([f'Tredje søgestreng: {third_str}'] if self.show_third_in_repr else []),
+            f'NOT-søgestreng: {not_str}',
+        ])
+
     @property
     def simple_string(self) -> str:
         """
@@ -423,3 +438,41 @@ class SearchString(Generic[Data]):
         [(1, 'test 12'), (2, 'test 12'), (9, 'test 9'), (12, 'test 12')]
         """
         return [ss for ss in search_strings if ss.match(text)]
+
+    @staticmethod
+    def find_all_sliding_window(
+        text: str,
+        search_strings: Iterable['SearchString'],
+        *,
+        window_size: int = 300,
+        step_size: int = 20,
+    ) -> List['SearchString']:
+        """
+        Find matches based on a sliding window method. Can be used if
+        underlying text is unsuitable for section- or sentence-tokenization
+        but it should still be enforced that matched text parts are not too
+        far apart.
+        Returns a list of all the search strings that matched some window
+        of the supplied text.
+        You can tune the sliding window using the `window_size` and
+        `step_size` parameters.
+
+        Example:
+        >>> ss = [SearchString('part1', 'part2', 'bad', data=None)]
+        >>> text = (' ' * 200).join(['part1', 'part2', 'bad.'])
+        >>> SearchString.find_all_sliding_window(text, ss, window_size=100)
+        []
+        >>> SearchString.find_all_sliding_window(text, ss, window_size=250)
+        [SearchString(part1, part2, bad)]
+        >>> SearchString.find_all_sliding_window(text, ss, window_size=500)
+        []
+        """
+        matched_ss_data = set()
+        ret_val = []
+        for start_idx in range(0, len(text), step_size):
+            window = text[start_idx:start_idx+window_size]
+            for ss in search_strings:
+                if ss.data not in matched_ss_data and ss.match(window):
+                    matched_ss_data.add(ss.data)
+                    ret_val.append(ss)
+        return ret_val
